@@ -153,7 +153,7 @@ class Player:
             weapons=None,
             country=self.country,
             top500=self.top500,
-            pronoun=self.pronoun if self.pronoun.source == search_uuid else None,
+            pronoun=self.pronoun if self.pronoun and (self.pronoun.source == search_uuid) else None,
             guid=self.guid)
 
     @property
