@@ -94,5 +94,5 @@ class Pronoun:
 
 
 if __name__ == '__main__':
-    test = Pronoun("they/them or she/her")
+    test = Pronoun("Discord description + ce/cer or she/her please :)")
     print(test.__str__())
