@@ -39,7 +39,7 @@ class TeamsHandler:
     def filter_to_source(self, source_id: Union[str, UUID]) -> 'TeamsHandler':
         search_uuid = source_id if isinstance(source_id, UUID) else UUID(source_id)
         return TeamsHandler(
-            teams={k: v for k, v in self._teams.items() if source_id in search_uuid}
+            teams={k: v for k, v in self._teams.items() if search_uuid in v}
         )
 
     def get_sources_for_team(self, team: UUID) -> List[UUID]:
